@@ -5,14 +5,14 @@ use strict;
 use Carp ();
 
 BEGIN {
-    $Text::CSV::VERSION = '1.08';
+    $Text::CSV::VERSION = '1.10';
     $Text::CSV::DEBUG   = 0;
 }
 
 # if use CSV_XS, requires version
 my $Module_XS  = 'Text::CSV_XS';
 my $Module_PP  = 'Text::CSV_PP';
-my $XS_Version = '0.52';
+my $XS_Version = '0.56';
 
 my $Is_Dynamic = 0;
 
@@ -270,9 +270,9 @@ perhaps better called ASV (anything separated values) rather than just CSV.
 
 =head1 VERSION
 
-    1.08
+    1.10
 
-This module is compatible with Text::CSV_XS B<0.52> or later.
+This module is compatible with Text::CSV_XS B<0.56> or later.
 
 =head2 BINARY MODE
 
@@ -293,6 +293,22 @@ are marked binary will also be marked UTF8.
 On combining (C<print ()> and C<combine ()>), if any of the combining
 fields was marked UTF8, the resulting string will be marked UTF8.
 
+For complete control over encoding, please use L<Text::CSV::Encoded>:
+
+    use Text::CSV::Encoded;
+    my $csv = Text::CSV::Encoded->new ({
+        encoding_in  => "iso-8859-1", # the encoding comes into   Perl
+        encoding_out => "cp1252",     # the encoding comes out of Perl
+    });
+
+    $csv = Text::CSV::Encoded->new ({ encoding  => "utf8" });
+    # combine () and print () accept *literally* utf8 encoded data
+    # parse () and getline () return *literally* utf8 encoded data
+
+    $csv = Text::CSV::Encoded->new ({ encoding  => undef }); # default
+    # combine () and print () accept UTF8 marked data
+    # parse () and getline () return UTF8 marked data
+
 =head1 SPECIFICATION
 
 See to L<Text::CSV_XS/SPECIFICATION>.
@@ -321,9 +337,10 @@ Currently the following attributes are available:
 
 =item eol
 
-An end-of-line string to add to rows, usually C<undef> (nothing,
-default), C<"\012"> (Line Feed) or C<"\015\012"> (Carriage Return,
-Line Feed). Cannot be longer than 7 (ASCII) characters.
+An end-of-line string to add to rows. C<undef> is replaced with an
+empty string. The default is C<$\>. Common values for C<eol> are
+C<"\012"> (Line Feed) or C<"\015\012"> (Carriage Return, Line Feed).
+Cannot be longer than 7 (ASCII) characters.
 
 If both C<$/> and C<eol> equal C<"\015">, parsing lines that end on
 only a Carriage Return without Line Feed, will be C<parse>d correct.
@@ -339,6 +356,8 @@ Limited to a single-byte character, usually in the range from 0x20
 The separation character can not be equal to the quote character.
 The separation character can not be equal to the escape character.
 
+See also L<Text::CSV_XS/CAVEATS>
+
 =item allow_whitespace
 
 When this option is set to true, whitespace (TAB's and SPACE's)
@@ -426,7 +445,7 @@ doubling the quote mark in a field escapes it:
   "foo","bar","Escape ""quote mark"" with two ""quote marks""","baz"
 
 If you change the default quote_char without changing the default
-escape_char, the escape_char will still be the quote mark.  If instead 
+escape_char, the escape_char will still be the quote mark.  If instead
 you want to escape the quote_char by doubling it, you will need to change
 the escape_char to be the same as what you changed the quote_char to.
 
@@ -518,7 +537,7 @@ is equivalent to
      quote_char          => '"',
      escape_char         => '"',
      sep_char            => ',',
-     eol                 => '',
+     eol                 => $\,
      always_quote        => 0,
      binary              => 0,
      keep_meta_info      => 0,
@@ -623,7 +642,7 @@ methods are meaningless, again.
 
 The C<getline_hr ()> and C<column_names ()> methods work together to allow
 you to have rows returned as hashrefs. You must call C<column_names ()>
-first to declare your column names. 
+first to declare your column names.
 
  $csv->column_names (qw( code name price description ));
  $hr = $csv->getline_hr ($io);
@@ -927,28 +946,6 @@ But how about it - calling worker module object?
  }
 
 
-
-=item Simple option
-
- $csv = Text::CSV->simple;
-
-is equivalent to
-
- $csv = Text::CSV->new ({
-     quote_char          => '"',
-     escape_char         => '"',
-     sep_char            => ',',
-     eol                 => '',
-     binary              => 1,
-     allow_loose_quotes  => 1,
-     allow_loose_escapes => 1,
-     allow_whitespace    => 1,
-     blank_is_undef      => 1,
- });
-
-Is it needless?
-
-
 =back
 
 See to L<Text::CSV_XS/TODO> and L<Text::CSV_PP/TODO>.
@@ -956,7 +953,7 @@ See to L<Text::CSV_XS/TODO> and L<Text::CSV_PP/TODO>.
 
 =head1 SEE ALSO
 
-L<Text::CSV_PP(3)> and L<Text::CSV_XS(3)>.
+L<Text::CSV_PP(3)>, L<Text::CSV_XS(3)> and L<Text::CSV::Encoded(3)>.
 
 
 =head1 AUTHORS and MAINTAINERS
